@@ -23,8 +23,10 @@ extern double GDSreadReal8(unsigned char* record);
 extern int GDSreadInt2(unsigned char* record);
 extern int GDSreadInt4(unsigned char* record);
 extern char * GDSreadString(unsigned char* record, int len);
+extern char * GDSEscPovString(char *s);
 extern int GDSrecordType(unsigned char record_type);
 extern void GDSaddDates(GDSlibrary* libptr, unsigned char* record);
 extern int GDSreadRecord(int gdsfildes, unsigned char **record, int *nbytes);
 extern void GDSunreadRecord(int gdsfildes, int nbytes);
-
+extern char *GDSpsStyleNoToTEXName(int i);
+extern char *GDSLayerToTEXName(layer *layerptr);
