@@ -36,6 +36,13 @@ BoxToPS(FILE *psfile, boxEl *box, PSStyle psStyle)
   return;
 }
 
+void
+BoxToPOV(FILE *povfile, boxEl *box, PSStyle psStyle)
+{
+ fprintf(povfile,"// box pov-printing not yet implemented.\n");
+ return;
+}
+
 void
 GDSfreeBox(GDScell *cell)
 {
@@ -52,6 +59,6 @@ GDSdupBox(boxEl *box)
 GDScell *
 GDSreadBox(int gdsfildes, GDSstruct *structptr)
 {
-  fprintf(stderr, "NOT YET IMPLEMENTED\n");
+  fprintf(stderr, "READING BOX NOT YET IMPLEMENTED\n");
   return NULL;
 }
