@@ -36,6 +36,13 @@ NodeToPS(FILE *psfile, nodeEl *node, PSStyle psStyle)
   return;
 }
 
+void
+NodeToPOV(FILE *povfile, nodeEl *node, PSStyle psStyle)
+{
+  fprintf(povfile,"// Node pov-printing not yet implemented.\n");
+  return;
+}
+
 void
 GDSfreeNode(GDScell *cell)
 {
@@ -52,6 +59,6 @@ GDSdupNode(nodeEl *node)
 GDScell *
 GDSreadNode(int gdsfildes, GDSstruct *structptr)
 {
-  fprintf(stderr, "NOT YET IMPLEMENTED\n");
+  fprintf(stderr, "READING NODE NOT YET IMPLEMENTED\n");
   return NULL;
 }
